@@ -19,16 +19,15 @@ import ch.qos.logback.access.spi.AccessEvent;
 import ch.qos.logback.access.spi.IAccessEvent;
 import ch.qos.logback.core.spi.PreSerializationTransformer;
 
-public class AccessEventPreSerializationTransformer implements
-    PreSerializationTransformer<IAccessEvent> {
+public class AccessEventPreSerializationTransformer implements PreSerializationTransformer<IAccessEvent> {
 
-  @Override
-  public Serializable transform(IAccessEvent event) {
-    if (event instanceof AccessEvent) {
-      return (AccessEvent)event;
-    } else {
-      throw new IllegalArgumentException("Unsupported type "+event.getClass().getName());
+    @Override
+    public Serializable transform(IAccessEvent event) {
+        if (event instanceof AccessEvent) {
+            return (AccessEvent) event;
+        } else {
+            throw new IllegalArgumentException("Unsupported type " + event.getClass().getName());
+        }
     }
-  }
 
 }
