@@ -27,6 +27,7 @@ import org.junit.Test;
 
 import ch.qos.logback.classic.turbo.NOPTurboFilter;
 import ch.qos.logback.core.CoreConstants;
+import ch.qos.logback.core.rolling.helper.FileNamePattern;
 import ch.qos.logback.core.status.StatusManager;
 
 public class LoggerContextTest {
@@ -249,7 +250,7 @@ public class LoggerContextTest {
         assertNotNull(fileCollisions);
         assertTrue(fileCollisions.isEmpty());
 
-        Map<String, String> filenamePatternCollisionMap = (Map<String, String>) lc.getObject(CoreConstants.RFA_FILENAME_PATTERN_COLLISION_MAP);
+        Map<String, FileNamePattern> filenamePatternCollisionMap = (Map<String, FileNamePattern>) lc.getObject(CoreConstants.RFA_FILENAME_PATTERN_COLLISION_MAP);
         assertNotNull(filenamePatternCollisionMap);
         assertTrue(filenamePatternCollisionMap.isEmpty());
     }
