@@ -13,16 +13,25 @@
  */
 package ch.qos.logback.classic;
 
-import java.io.*;
+import static junit.framework.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.ObjectOutputStream;
+import java.util.ArrayList;
+import java.util.List;
 
-import ch.qos.logback.core.util.CoreTestConstants;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 import org.slf4j.LoggerFactory;
 
-import static junit.framework.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import ch.qos.logback.classic.net.server.HardenedLoggingEventInputStream;
+import ch.qos.logback.core.net.HardenedObjectInputStream;
+import ch.qos.logback.core.util.CoreTestConstants;
 
 public class LoggerSerializationTest {
 
@@ -35,8 +44,9 @@ public class LoggerSerializationTest {
 
     ByteArrayOutputStream bos;
     ObjectOutputStream oos;
-    ObjectInputStream inputStream;
-
+    HardenedLoggingEventInputStream hardenedLoggingEventInputStream;
+    List<String> whitelist = new ArrayList<String>();
+    
     @Before
     public void setUp() throws Exception {
         lc = new LoggerContext();
@@ -45,6 +55,7 @@ public class LoggerSerializationTest {
         // create the byte output stream
         bos = new ByteArrayOutputStream();
         oos = new ObjectOutputStream(bos);
+        whitelist.add(Foo.class.getName());
     }
 
     @After
@@ -110,17 +121,17 @@ public class LoggerSerializationTest {
     private Foo writeAndRead(Foo foo) throws IOException, ClassNotFoundException {
         writeObject(oos, foo);
         ByteArrayInputStream bis = new ByteArrayInputStream(bos.toByteArray());
-        inputStream = new ObjectInputStream(bis);
-        Foo fooBack = readFooObject(inputStream);
-        inputStream.close();
+        hardenedLoggingEventInputStream =  new HardenedLoggingEventInputStream(bis, whitelist);
+        Foo fooBack = readFooObject(hardenedLoggingEventInputStream);
+        hardenedLoggingEventInputStream.close();
         return fooBack;
     }
 
-    Foo readFooObject(ObjectInputStream inputStream) throws IOException, ClassNotFoundException {
+    Foo readFooObject(HardenedObjectInputStream inputStream) throws IOException, ClassNotFoundException {
         return (Foo) readObject(inputStream);
     }
 
-    private Object readObject(ObjectInputStream inputStream) throws IOException, ClassNotFoundException {
+    private Object readObject(HardenedObjectInputStream inputStream) throws IOException, ClassNotFoundException {
         return inputStream.readObject();
     }
 
@@ -133,7 +144,7 @@ public class LoggerSerializationTest {
     @Test
     public void testCompatibilityWith_v1_0_11() throws IOException, ClassNotFoundException {
         FileInputStream fis = new FileInputStream(SERIALIZATION_PREFIX + "logger_v1.0.11.ser");
-        ObjectInputStream ois = new ObjectInputStream(fis);
+        HardenedObjectInputStream ois = new HardenedLoggingEventInputStream(fis); // new String[] {Logger.class.getName(), LoggerRemoteView.class.getName()});
         Logger a = (Logger) ois.readObject();
         ois.close();
         assertEquals("a", a.getName());
@@ -145,7 +156,7 @@ public class LoggerSerializationTest {
     @Test
     public void testCompatibilityWith_v1_0_12() throws IOException, ClassNotFoundException {
         FileInputStream fis = new FileInputStream(SERIALIZATION_PREFIX + "logger_v1.0.12.ser");
-        ObjectInputStream ois = new ObjectInputStream(fis);
+        HardenedObjectInputStream ois = new HardenedObjectInputStream(fis, new String[] {Logger.class.getName()});
         Logger a = (Logger) ois.readObject();
         ois.close();
         assertEquals("a", a.getName());
