@@ -18,9 +18,7 @@ import org.junit.runners.Suite;
 import org.junit.runners.Suite.SuiteClasses;
 
 @RunWith(Suite.class)
-@SuiteClasses( { ContextListenerTest.class, CallerDataTest.class,
-    LoggerComparatorTest.class, LoggingEventTest.class, LoggingEventSerializationTest.class,
-    LoggingEventSerializationPerfTest.class, ThrowableProxyTest.class,
-    PackagingDataCalculatorTest.class })
-public class PackageTest  {
+@SuiteClasses({ ContextListenerTest.class, CallerDataTest.class, LoggerComparatorTest.class, LoggingEventTest.class, LoggingEventSerializationTest.class,
+        LoggingEventSerializationPerfTest.class, ThrowableProxyTest.class, PackagingDataCalculatorTest.class })
+public class PackageTest {
 }
\ No newline at end of file
