@@ -21,11 +21,10 @@ import ch.qos.logback.core.spi.FilterReply;
 
 public class NOPTurboFilter extends TurboFilter {
 
-  @Override
-  public FilterReply decide(final Marker marker, final Logger logger, final Level level, final String format,
-      final Object[] params, final Throwable t) {
-   
-    return FilterReply.NEUTRAL;
-  }
+    @Override
+    public FilterReply decide(final Marker marker, final Logger logger, final Level level, final String format, final Object[] params, final Throwable t) {
+
+        return FilterReply.NEUTRAL;
+    }
 
 }
