@@ -44,18 +44,20 @@ public class OutputStreamAppender<E> extends UnsynchronizedAppenderBase<E> {
     /**
      * All synchronization in this class is done via the lock object.
      */
-    protected final ReentrantLock lock = new ReentrantLock(true);
+    protected final ReentrantLock lock = new ReentrantLock(false);
 
     /**
      * This is the {@link OutputStream outputStream} where output will be written.
      */
     private OutputStream outputStream;
 
+    boolean immediateFlush = true;
+
     /**
-     * The underlying output stream used by this appender.
-     * 
-     * @return
-     */
+    * The underlying output stream used by this appender.
+    * 
+    * @return
+    */
     public OutputStream getOutputStream() {
         return outputStream;
     }
@@ -133,21 +135,11 @@ public class OutputStreamAppender<E> extends UnsynchronizedAppenderBase<E> {
         }
     }
 
-    void encoderInit() {
-        if (encoder != null && this.outputStream != null) {
-            try {
-                encoder.init(outputStream);
-            } catch (IOException ioe) {
-                this.started = false;
-                addStatus(new ErrorStatus("Failed to initialize encoder for appender named [" + name + "].", this, ioe));
-            }
-        }
-    }
-
     void encoderClose() {
         if (encoder != null && this.outputStream != null) {
             try {
-                encoder.close();
+                byte[] footer = encoder.footerBytes();
+                writeBytes(footer);
             } catch (IOException ioe) {
                 this.started = false;
                 addStatus(new ErrorStatus("Failed to write footer for appender named [" + name + "].", this, ioe));
@@ -170,7 +162,6 @@ public class OutputStreamAppender<E> extends UnsynchronizedAppenderBase<E> {
         try {
             // close any previously opened output stream
             closeOutputStream();
-
             this.outputStream = outputStream;
             if (encoder == null) {
                 addWarn("Encoder has not been set. Cannot invoke its init method.");
@@ -183,8 +174,35 @@ public class OutputStreamAppender<E> extends UnsynchronizedAppenderBase<E> {
         }
     }
 
+    void encoderInit() {
+        if (encoder != null && this.outputStream != null) {
+            try {
+                byte[] header = encoder.headerBytes();
+                writeBytes(header);
+            } catch (IOException ioe) {
+                this.started = false;
+                addStatus(new ErrorStatus("Failed to initialize encoder for appender named [" + name + "].", this, ioe));
+            }
+        }
+    }
     protected void writeOut(E event) throws IOException {
-        this.encoder.doEncode(event);
+        byte[] byteArray = this.encoder.encode(event);
+        writeBytes(byteArray);
+    }
+
+    private void writeBytes(byte[] byteArray) throws IOException {
+        if(byteArray == null || byteArray.length == 0)
+            return;
+        
+        lock.lock();
+        try {
+            this.outputStream.write(byteArray);
+            if (immediateFlush) {
+                this.outputStream.flush();
+            }
+        } finally {
+            lock.unlock();
+        }
     }
 
     /**
@@ -207,12 +225,11 @@ public class OutputStreamAppender<E> extends UnsynchronizedAppenderBase<E> {
             // the synchronization prevents the OutputStream from being closed while we
             // are writing. It also prevents multiple threads from entering the same
             // converter. Converters assume that they are in a synchronized block.
-            lock.lock();
-            try {
-                writeOut(event);
-            } finally {
-                lock.unlock();
-            }
+            // lock.lock();
+
+            byte[] byteArray = this.encoder.encode(event);
+            writeBytes(byteArray);
+
         } catch (IOException ioe) {
             // as soon as an exception occurs, move to non-started state
             // and add a single ErrorStatus to the SM.
@@ -229,4 +246,12 @@ public class OutputStreamAppender<E> extends UnsynchronizedAppenderBase<E> {
         this.encoder = encoder;
     }
 
+    public boolean isImmediateFlush() {
+        return immediateFlush;
+    }
+
+    public void setImmediateFlush(boolean immediateFlush) {
+        this.immediateFlush = immediateFlush;
+    }
+
 }
