@@ -15,33 +15,32 @@ package ch.qos.logback.core.boolex;
 
 import ch.qos.logback.core.spi.ContextAwareBase;
 
-abstract public class EventEvaluatorBase<E> extends ContextAwareBase implements
-    EventEvaluator<E> {
+abstract public class EventEvaluatorBase<E> extends ContextAwareBase implements EventEvaluator<E> {
 
-  String name;
-  boolean started;
+    String name;
+    boolean started;
 
-  public String getName() {
-    return name;
-  }
-
-  public void setName(String name) {
-    if (this.name != null) {
-      throw new IllegalStateException("name has been already set");
+    public String getName() {
+        return name;
     }
-    this.name = name;
-  }
-  
-  public boolean isStarted() {
-    return started;
-  }
 
-  public void start() {
-    started = true;
-  }
+    public void setName(String name) {
+        if (this.name != null) {
+            throw new IllegalStateException("name has been already set");
+        }
+        this.name = name;
+    }
 
-  public void stop() {
-    started = false;
-  }
+    public boolean isStarted() {
+        return started;
+    }
+
+    public void start() {
+        started = true;
+    }
+
+    public void stop() {
+        started = false;
+    }
 
 }
