@@ -23,14 +23,13 @@ import ch.qos.logback.core.joran.spi.InterpretationContext;
  */
 public class ContextPropertyAction extends Action {
 
-  @Override
-  public void begin(InterpretationContext ec, String name, Attributes attributes)
-      throws ActionException {
-    addError("The [contextProperty] element has been removed. Please use [substitutionProperty] element instead");
-  }
+    @Override
+    public void begin(InterpretationContext ec, String name, Attributes attributes) throws ActionException {
+        addError("The [contextProperty] element has been removed. Please use [substitutionProperty] element instead");
+    }
 
-  @Override
-  public void end(InterpretationContext ec, String name) throws ActionException {
-  }
+    @Override
+    public void end(InterpretationContext ec, String name) throws ActionException {
+    }
 
 }
