@@ -14,6 +14,7 @@
 package ch.qos.logback.core.rolling.helper;
 
 import java.util.Date;
+import java.util.concurrent.Future;
 
 import ch.qos.logback.core.spi.ContextAware;
 
@@ -23,6 +24,8 @@ import ch.qos.logback.core.spi.ContextAware;
  * @author Ceki G&uuml;lc&uuml;
  */
 public interface ArchiveRemover extends ContextAware {
-  void clean(Date now);
-  void setMaxHistory(int maxHistory);
-} 
\ No newline at end of file
+    void clean(Date now);
+    void setMaxHistory(int maxHistory);
+    void setTotalSizeCap(long totalSizeCap);
+    Future<?> cleanAsynchronously(Date now);
+}
\ No newline at end of file
