@@ -21,26 +21,26 @@ import ch.qos.logback.core.pattern.DynamicConverter;
  * 
  * @author Ceki Gulcu
  */
-public class IntegerTokenConverter extends DynamicConverter implements MonoTypedConverter {
+public class IntegerTokenConverter extends DynamicConverter<Object> implements MonoTypedConverter {
 
-  public final static String CONVERTER_KEY = "i";
-  
-  public String convert(int i) {
-    return Integer.toString(i);
-  }
+    public final static String CONVERTER_KEY = "i";
 
-  public String convert(Object o) {
-    if(o == null) {
-      throw new IllegalArgumentException("Null argument forbidden");
+    public String convert(int i) {
+        return Integer.toString(i);
     }
-    if(o instanceof Integer) {
-      Integer i = (Integer) o;
-      return convert(i.intValue());
-    } 
-    throw new IllegalArgumentException("Cannot convert "+o+" of type"+o.getClass().getName());
-  }
 
-  public boolean isApplicable(Object o) {
-    return (o instanceof Integer);
-  }
+    public String convert(Object o) {
+        if (o == null) {
+            throw new IllegalArgumentException("Null argument forbidden");
+        }
+        if (o instanceof Integer) {
+            Integer i = (Integer) o;
+            return convert(i.intValue());
+        }
+        throw new IllegalArgumentException("Cannot convert " + o + " of type" + o.getClass().getName());
+    }
+
+    public boolean isApplicable(Object o) {
+        return (o instanceof Integer);
+    }
 }
