@@ -13,7 +13,6 @@
  */
 package ch.qos.logback.core.contention;
 
-
 /**
  * Useful scaffolding to measure the throughput of certain operations when
  * invoked by multiple threads.
@@ -24,25 +23,23 @@ package ch.qos.logback.core.contention;
  */
 public class ThreadedThroughputCalculator extends MultiThreadedHarness {
 
+    public ThreadedThroughputCalculator(long overallDurationInMillis) {
+        super(overallDurationInMillis);
+    }
 
-  public ThreadedThroughputCalculator(long overallDurationInMillis) {
-    super(overallDurationInMillis);
-  }
+    public void printThroughput(String msg) throws InterruptedException {
+        printThroughput(msg, false);
+    }
 
-  public void printThroughput(String msg) throws InterruptedException {
-    printThroughput(msg, false);
-  }
-  
-  public void printThroughput(String msg, boolean detailed) throws InterruptedException {
-    long sum = 0;
-    for (RunnableWithCounterAndDone r : runnableArray) {
-      if(detailed) {
-        System.out.println(r +" count="+r.getCounter());
-      }
-      sum += r.getCounter();
+    public void printThroughput(String msg, boolean detailed) throws InterruptedException {
+        long sum = 0;
+        for (RunnableWithCounterAndDone r : runnableArray) {
+            if (detailed) {
+                System.out.println(r + " count=" + r.getCounter());
+            }
+            sum += r.getCounter();
+        }
+
+        System.out.println(msg + "total of " + sum + " operations, or " + ((sum) / overallDurationInMillis) + " operations per millisecond");
     }
-    
-    System.out.println(msg + "total of " + sum + " operations, or "
-        + ((sum) / overallDurationInMillis) + " operations per millisecond");
-  }
 }
