@@ -41,10 +41,13 @@ public class House {
     List<Window> windowList = new ArrayList<Window>();
     List<SwimmingPool> largePoolList = new ArrayList<SwimmingPool>();
 
+    Orange orange;
+    
     public String getCamelCase() {
         return camelCase;
     }
 
+    
     public void setCamelCase(String camelCase) {
         this.camelCase = camelCase;
     }
@@ -150,6 +153,10 @@ public class House {
     public void setCharset(Charset charset) {
         this.charset = charset;
     }
+    
+    public void setOrange(Orange o) {
+        this.orange = o;
+    }
 }
 
 class Door {
@@ -177,4 +184,4 @@ class LargeSwimmingPoolImpl implements SwimmingPool {
 
 enum HouseColor {
     WHITE, BLUE
-}
\ No newline at end of file
+}
