@@ -18,6 +18,7 @@ import org.junit.runners.Suite;
 
 @RunWith(Suite.class)
 @Suite.SuiteClasses({ RenameUtilTest.class, SizeBasedRollingTest.class, TimeBasedRollingTest.class, TimeBasedRollingWithArchiveRemoval_Test.class,
-        MultiThreadedRollingTest.class, SizeAndTimeBasedFNATP_Test.class, RollingFileAppenderTest.class, ch.qos.logback.core.rolling.helper.PackageTest.class })
+        MultiThreadedRollingTest.class, SizeAndTimeBasedFNATP_Test.class, RollingFileAppenderTest.class, 
+        CollisionDetectionTest.class, ch.qos.logback.core.rolling.helper.PackageTest.class })
 public class PackageTest {
 }
